summaryrefslogtreecommitdiff
path: root/source3/auth
diff options
context:
space:
mode:
authorTim Potter <tpot@samba.org>2002-08-22 09:48:06 +0000
committerTim Potter <tpot@samba.org>2002-08-22 09:48:06 +0000
commit3276da43142bb4a0886747dabcfce6a436f11f25 (patch)
tree71e229593da5ec76d41d958584140ade30268463 /source3/auth
parentc9c404b26cb82b155f9170bc0dc2b6ba934531e4 (diff)
downloadsamba-3276da43142bb4a0886747dabcfce6a436f11f25.tar.gz
samba-3276da43142bb4a0886747dabcfce6a436f11f25.tar.bz2
samba-3276da43142bb4a0886747dabcfce6a436f11f25.zip
Spelling fixes.
(This used to be commit 24fa84bda49a3a77fbc092652a0b6b132f06ff7c)
Diffstat (limited to 'source3/auth')
-rw-r--r--source3/auth/auth_sam.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/source3/auth/auth_sam.c b/source3/auth/auth_sam.c
index 50f1e5dac9..58def0567a 100644
--- a/source3/auth/auth_sam.c
+++ b/source3/auth/auth_sam.c
@@ -233,17 +233,17 @@ static NTSTATUS sam_password_ok(const struct auth_context *auth_context,
return NT_STATUS_OK;
} else {
if (lp_ntlm_auth()) {
- /* Apparently NT accepts NT responses in the LM feild
- - I think this is related to Win9X pass-though authenticaion
+ /* Apparently NT accepts NT responses in the LM field
+ - I think this is related to Win9X pass-though authentication
*/
- DEBUG(4,("sam_password_ok: Checking NT MD4 password in LM feild\n"));
+ DEBUG(4,("sam_password_ok: Checking NT MD4 password in LM field\n"));
if (smb_pwd_check_ntlmv1(user_info->lm_resp,
nt_pw, auth_context->challenge,
user_sess_key))
{
return NT_STATUS_OK;
} else {
- DEBUG(3,("sam_password_ok: NT MD4 password in LM feild failed for user %s\n",pdb_get_username(sampass)));
+ DEBUG(3,("sam_password_ok: NT MD4 password in LM field failed for user %s\n",pdb_get_username(sampass)));
return NT_STATUS_WRONG_PASSWORD;
}
}